#
# spec file for package qt6-qt5compat
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define real_version 6.6.3
%define short_version 6.6
%define tar_name qt5compat-everywhere-src
%define tar_suffix %{nil}
#
%global qt6_flavor docs%{nil}
%if "%{qt6_flavor}" == "docs"
%define pkg_suffix -docs
%endif
#
Name:           qt6-qt5compat%{?pkg_suffix}
Version:        6.6.3
Release:        150600.1.1
Summary:        Unsupported Qt 5 APIs for Qt 6
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
URL:            https://www.qt.io
Source:         https://download.qt.io/official_releases/qt/%{short_version}/%{real_version}%{tar_suffix}/submodules/%{tar_name}-%{real_version}%{tar_suffix}.tar.xz
Source99:       qt6-qt5compat-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  qt6-core-private-devel
BuildRequires:  qt6-gui-private-devel
BuildRequires:  qt6-qml-private-devel
BuildRequires:  qt6-quick-private-devel
BuildRequires:  qt6-shadertools-private-devel
BuildRequires:  cmake(Qt6Core) = %{real_version}
BuildRequires:  cmake(Qt6Gui) = %{real_version}
BuildRequires:  cmake(Qt6Network) = %{real_version}
BuildRequires:  cmake(Qt6Quick) = %{real_version}
BuildRequires:  cmake(Qt6ShaderTools) = %{real_version}
BuildRequires:  cmake(Qt6Xml) = %{real_version}
BuildRequires:  pkgconfig(icu-i18n)
%if "%{qt6_flavor}" == "docs"
BuildRequires:  qt6-tools
%{qt6_doc_packages}
%endif

%description
The Qt 6 Compat library provides unsupported Qt 5 APIs which can be useful
while porting Qt 5 code.

%if !%{qt6_docs_flavor}

%package imports
Summary:        Qt 6 Core 5 Compat QML files and plugins

%description imports
QML files and plugins from the Qt 6 Core5Compat module.
This package shall be used while porting away from qtgraphicaleffects.

%package -n libQt6Core5Compat6
Summary:        Qt 6 Core 5 Compat library

%description -n libQt6Core5Compat6
The Qt 6 Core 5 Compat library

%package devel
Summary:        Qt 6 Core 5 Compat library - Development files
Requires:       libQt6Core5Compat6 = %{version}
Requires:       cmake(Qt6Core) = %{real_version}

%description devel
Development files for the Qt 6 Core 5 Compat library

%package private-devel
Summary:        Non-ABI stable API for the Qt 6 Qt5 Compat library
Requires:       cmake(Qt6Core5Compat) = %{real_version}
%requires_eq    qt6-core-private-devel

%description private-devel
This package provides private headers of libQt6Core5Compat that do not have any
ABI or API guarantees.

%endif

%prep
%autosetup -p1 -n %{tar_name}-%{real_version}%{tar_suffix}

%build
%cmake_qt6

%{qt6_build}

%install
%{qt6_install}

%if !%{qt6_docs_flavor}

%fdupes %{buildroot}

# CMake files are not needed for plugins
rm -r %{buildroot}%{_qt6_cmakedir}/Qt6Qml/QmlPlugins

%ldconfig_scriptlets -n libQt6Core5Compat6

%files imports
%{_qt6_qmldir}/Qt5Compat/

%files -n libQt6Core5Compat6
%license LICENSES/*
%{_qt6_libdir}/libQt6Core5Compat.so.*

%files devel
%{_qt6_cmakedir}/Qt6/FindWrapIconv.cmake
%{_qt6_cmakedir}/Qt6BuildInternals/StandaloneTests/Qt5CompatTestsConfig.cmake
%{_qt6_cmakedir}/Qt6Core5Compat/
%{_qt6_descriptionsdir}/Core5Compat.json
%{_qt6_includedir}/QtCore5Compat/
%{_qt6_libdir}/libQt6Core5Compat.prl
%{_qt6_libdir}/libQt6Core5Compat.so
%{_qt6_metatypesdir}/qt6core5compat_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_core5compat.pri
%{_qt6_pkgconfigdir}/Qt6Core5Compat.pc
%exclude %{_qt6_includedir}/QtCore5Compat/%{real_version}

%files private-devel
%{_qt6_includedir}/QtCore5Compat/%{real_version}/
%{_qt6_mkspecsdir}/modules/qt_lib_core5compat_private.pri

%endif

%changelog
* Tue Mar 26 2024 christophe@krop.fr
- Update to 6.6.3:
  * https://www.qt.io/blog/qt-6.6.3-released
* Wed Feb 14 2024 christophe@krop.fr
- Update to 6.6.2
  * https://www.qt.io/blog/qt-6.6.2-released
* Mon Nov 27 2023 christophe@krop.fr
- Update to 6.6.1:
  * https://www.qt.io/blog/qt-6.6.1-released
* Tue Oct 10 2023 christophe@krop.fr
- Update to 6.6.0
  * https://www.qt.io/blog/qt-6.6-released
* Thu Sep 28 2023 christophe@krop.fr
- Update to 6.5.3
  * https://www.qt.io/blog/qt-6.5.3-released
* Thu Jul 20 2023 christophe@krop.fr
- Update to 6.5.2
  * https://www.qt.io/blog/qt-6.5.2-released-1
* Fri Jun 30 2023 christophe@krop.fr
- Update subpackages requirements
* Wed May 24 2023 christophe@krop.fr
- Update to 6.5.1
  * https://www.qt.io/blog/qt-6.5.1-released
* Mon Apr  3 2023 christophe@krop.fr
- Update to 6.5.0
  * https://www.qt.io/blog/qt-6.5-lts-released
* Thu Mar 16 2023 christophe@krop.fr
- Update to 6.4.3:
  * https://www.qt.io/blog/qt-6.4.3-released
* Fri Jan  6 2023 christophe@krop.fr
- Update to 6.4.2:
  * https://www.qt.io/blog/qt-6.4.2-released
* Tue Nov 15 2022 christophe@krop.fr
- Update to 6.4.1:
  * https://www.qt.io/blog/qt-6.4.1-released
* Thu Sep 29 2022 christophe@krop.fr
- Update to 6.4.0:
  * https://www.qt.io/blog/qt-6.4-released
* Fri Sep 16 2022 christophe@krop.fr
- Update to 6.4.0 RC
* Fri Sep  9 2022 christophe@krop.fr
- Update to 6.3.2:
  * https://www.qt.io/blog/qt-6.3.2-released
* Fri Jun 17 2022 christophe@krop.fr
- Update to 6.3.1:
  * https://www.qt.io/blog/qt-6.3.1-released
* Fri Apr  8 2022 christophe@krop.fr
- Update to 6.3.0:
  * https://www.qt.io/blog/qt-6.3-released
* Tue Mar 29 2022 christophe@krop.fr
- Update to 6.3.0-rc
* Mon Mar 21 2022 christophe@krop.fr
- Update to 6.2.4
  * https://www.qt.io/blog/qt-6.2.4-released
* Mon Jan 31 2022 christophe@krop.fr
- Update to 6.2.3:
  * https://www.qt.io/blog/qt-6.2.3-released
* Wed Dec  1 2021 christophe@krop.fr
- Update to 6.2.2
  * https://www.qt.io/blog/qt-6.2.2-released
- Make sure all dependencies are present when installing devel
  packages. Qt >= 6.2.2 is much less permissive.
* Tue Oct 26 2021 christophe@krop.fr
- Update to 6.2.1
  * https://www.qt.io/blog/qt-6.2.1-released
* Thu Sep 30 2021 christophe@krop.fr
- Update to 6.2.0:
  * https://www.qt.io/blog/qt-6.2-lts-released
* Sat Sep 25 2021 christophe@krop.fr
- Update to 6.2.0-rc2
* Thu Sep 16 2021 christophe@krop.fr
- Update to 6.2.0-rc
* Thu Sep  9 2021 christophe@krop.fr
- Update to 6.2.0-beta4
* Wed Sep  1 2021 christophe@krop.fr
- Update to 6.1.3:
  * https://www.qt.io/blog/qt-6.1.3-released
* Fri Jul  2 2021 christophe@krop.fr
- Update to 6.1.2. New bugfix release:
  * https://www.qt.io/blog/qt-6.1.2-released
* Tue Jun  8 2021 christophe@krop.fr
- Update to 6.1.1:
  * https://www.qt.io/blog/qt-6.1.1-released
* Thu May  6 2021 christophe@krop.fr
- Update to 6.1.0:
  * https://www.qt.io/blog/qt-6.1-released
* Fri Apr 23 2021 christophe@krop.fr
- Update to 6.1.0-rc.
* Tue Apr 13 2021 christophe@krop.fr
- Update to 6.1.0-beta3.
* Wed Mar 31 2021 christophe@krop.fr
- Update to 6.0.3
  * https://www.qt.io/blog/qt-6.0.3-released
* Fri Mar 19 2021 christophe@krop.fr
- Update to 6.1.0-beta2
* Fri Mar  5 2021 christophe@krop.fr
- Update to 6.1.0-beta1
  https://www.qt.io/blog/qt-6.1-beta-released
* Fri Mar  5 2021 christophe@krop.fr
- Update to 6.0.2:
  https://www.qt.io/blog/qt-6.0.2-released
* Wed Feb  3 2021 christophe@krop.fr
- Update to 6.0.1
  https://www.qt.io/blog/qt-6.0.1-released
* Wed Dec 16 2020 christophe@krop.fr
- Use a different 'Name' when building the docs flavor.
* Tue Dec  8 2020 christophe@krop.fr
- Update to 6.0.0:
  * https://www.qt.io/blog/qt-6.0-released
* Wed Dec  2 2020 christophe@krop.fr
- Qt 6.0.0 RC2
* Wed Nov 25 2020 christophe@krop.fr
- Update to 6.0.0~rc1
* Tue Nov 17 2020 christophe@krop.fr
- Update to 6.0.0~beta5
* Tue Nov 10 2020 christophe@krop.fr
- Update to 6.0.0~beta4
* Tue Oct 20 2020 christophe@krop.fr
- Update to 6.0.0beta1
  https://www.qt.io/blog/qt-6.0-beta-released
* Tue Oct  6 2020 christophe@krop.fr
- Update to 6.0.0-alpha
  https://www.qt.io/blog/qt-6.0-alpha-released
* Sat Aug  8 2020 jonas@jkvinge.net
- Add qt6-qt5compat
